summaryrefslogtreecommitdiffstats
path: root/src/H5Oflush.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
commit1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96 (patch)
treec1f53073ff700c02397231fec2b2075a7391d87f /src/H5Oflush.c
parentdeb75622ca18958ea729c7184c4bc5ea0e029280 (diff)
downloadhdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.zip
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.gz
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.bz2
Switch driver | plugin => connector.
Diffstat (limited to 'src/H5Oflush.c')
-rw-r--r--src/H5Oflush.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/H5Oflush.c b/src/H5Oflush.c
index d8d0430..4b429f8 100644
--- a/src/H5Oflush.c
+++ b/src/H5Oflush.c
@@ -299,7 +299,7 @@ H5O_refresh_metadata(hid_t oid, H5O_loc_t oloc)
H5O_loc_t obj_oloc;
H5G_name_t obj_path;
H5O_shared_t cached_H5O_shared;
- H5VL_t *plugin = NULL;
+ H5VL_t *connector = NULL;
/* Create empty object location */
obj_loc.oloc = &obj_oloc;
@@ -317,29 +317,29 @@ H5O_refresh_metadata(hid_t oid, H5O_loc_t oloc)
if(H5T_save_refresh_state(oid, &cached_H5O_shared) < 0)
HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to save datatype state")
/* Get the VOL object from the ID and cache a pointer to the plugin.
* The vol_obj will disappear when the underlying object is closed, so
* we can't use that directly.
*/
if(NULL == (vol_obj = H5VL_vol_object(oid)))
HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
- plugin = vol_obj->plugin;
+ connector = vol_obj->connector;
- /* Bump the number of references on the VOL plugin.
- * If you don't do this, VDS refreshes can accidentally close the plugin.
+ /* Bump the number of references on the VOL connector.
+ * If you don't do this, VDS refreshes can accidentally close the connector.
*/
- plugin->nrefs++;
+ connector->nrefs++;
/* Close object & evict its metadata */
if((H5O__refresh_metadata_close(oid, oloc, &obj_loc)) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
/* Re-open the object, re-fetching its metadata */
- if((H5O_refresh_metadata_reopen(oid, &obj_loc, plugin, FALSE)) < 0)
+ if((H5O_refresh_metadata_reopen(oid, &obj_loc, connector, FALSE)) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
- /* Restore the number of references on the VOL plugin */
- plugin->nrefs--;
+ /* Restore the number of references on the VOL connector */
+ connector->nrefs--;
/* Restore important datatype state */
if(H5I_get_type(oid) == H5I_DATATYPE)
@@ -442,7 +442,7 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5O_refresh_metadata_reopen(hid_t oid, H5G_loc_t *obj_loc, H5VL_t *vol_plugin, hbool_t start_swmr)
+H5O_refresh_metadata_reopen(hid_t oid, H5G_loc_t *obj_loc, H5VL_t *vol_connector, hbool_t start_swmr)
{
void *object = NULL; /* Object for this operation */
H5I_type_t type; /* Type of object for the ID */
@@ -452,7 +452,7 @@ H5O_refresh_metadata_reopen(hid_t oid, H5G_loc_t *obj_loc, H5VL_t *vol_plugin, h
/* Sanity check */
HDassert(obj_loc);
- HDassert(vol_plugin);
+ HDassert(vol_connector);
/* Get object's type */
type = H5I_get_type(oid);
@@ -499,7 +499,7 @@ H5O_refresh_metadata_reopen(hid_t oid, H5G_loc_t *obj_loc, H5VL_t *vol_plugin, h
} /* end switch */
/* Re-register ID for the object */
- if((H5VL_register_using_existing_id(type, object, vol_plugin, TRUE, oid)) < 0)
+ if((H5VL_register_using_existing_id(type, object, vol_connector, TRUE, oid)) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to re-register object ID after refresh")
done:
@@ -317,29 +317,29 @@ H5O_refresh_metadata(hid_t oid, H5O_loc_t oloc)
if(H5T_save_refresh_state(oid, &cached_H5O_shared) < 0)
HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to save datatype state")
- /* Get the VOL object from the ID and cache a pointer to the plugin.
+ /* Get the VOL object from the ID and cache a pointer to the connector.
* The vol_obj will disappear when the underlying object is closed, so
* we can't use that directly.